# bitpesa-sdk

Bitpesa - the Ruby gem for the BitPesa API

Reference documentation for the BitPesa API V1

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 0.2.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

For more information, please visit:

* [API Documentation](https://github.com/bitpesa/api-documentation)
  * [Onboarding guide](https://github.com/bitpesa/api-documentation/blob/master/quick-integration.md)
  * [Transaction flow](https://github.com/bitpesa/api-documentation/blob/master/transaction-flow.md)
  * [Additional features](https://github.com/bitpesa/api-documentation/blob/master/additional-features.md)
* [API Specification](https://api.bitpesa.co/documentation)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build bitpesa-sdk.gemspec
```

Then either install the gem locally:

```shell
gem install ./bitpesa-sdk-0.2.0.gem
```
(for development, run `gem install --dev ./bitpesa-sdk-0.2.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'bitpesa-sdk', '~> 0.2.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/bitpesa/bitpesa-ruby-sdk, then add the following in the Gemfile:

    gem 'bitpesa-sdk', :git => 'https://github.com/bitpesa/bitpesa-ruby-sdk.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

## Webhooks

To parse webhooks you can use the following snippet:
```ruby
webhook_content = "{ (...) }"

webhook_api = Bitpesa::ApiClient.new
webhook = webhook_api.parse_response(webhook_content, "Webhook")

if webhook['event'].start_with?('transaction')
  transaction_webhook = webhook_api.parse_response(webhook_content, 'TransactionWebhook')
  puts transaction_webhook.object.to_s
elsif webhook['event'].start_with?('recipient')
  recipient_webhook = webhook_api.parse_response(webhook_content, 'RecipientWebhook')
  puts recipient_webhook.object.to_s
elsif webhook['event'].start_with?('payout_method')
  payout_method_webhook = webhook_api.parse_response(webhook_content, 'PayoutMethodWebhook')
  puts payout_method_webhook.object.to_s
elsif webhook['event'].start_with?('sender')
  sender_webhook = webhook_api.parse_response(webhook_content, 'SenderWebhook')
  puts sender_webhook.object.to_s
elsif webhook['event'].start_with?('document')
  document_webhook = webhook_api.parse_response(webhook_content, 'DocumentWebhook')
  puts document_webhook.object.to_s
else
  puts webhook
end
```

## Documentation for API Endpoints

All URIs are relative to *https://api-sandbox.bitpesa.co/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Bitpesa::APILogsApi* | [**get_api_log**](docs/APILogsApi.md#get_api_log) | **GET** /api_logs/{API Log ID} | Fetch an individual API log
*Bitpesa::APILogsApi* | [**get_api_logs**](docs/APILogsApi.md#get_api_logs) | **GET** /api_logs | Fetch a list of API logs
*Bitpesa::AccountDebitsApi* | [**get_accounts_debit**](docs/AccountDebitsApi.md#get_accounts_debit) | **GET** /accounts/debits/{Account Debit ID} | Fetching an account debit
*Bitpesa::AccountDebitsApi* | [**get_accounts_debits**](docs/AccountDebitsApi.md#get_accounts_debits) | **GET** /accounts/debits | Listing Accounts debits
*Bitpesa::AccountDebitsApi* | [**post_accounts_debits**](docs/AccountDebitsApi.md#post_accounts_debits) | **POST** /accounts/debits | Creating an account debit
*Bitpesa::AccountValidationApi* | [**post_account_validations**](docs/AccountValidationApi.md#post_account_validations) | **POST** /account_validations | Validates the existence of a bank account
*Bitpesa::AccountsApi* | [**get_account**](docs/AccountsApi.md#get_account) | **GET** /accounts/{Currency} | Fetches account balance for specified currrency
*Bitpesa::AccountsApi* | [**get_accounts**](docs/AccountsApi.md#get_accounts) | **GET** /accounts | Fetches account balances for all currencies
*Bitpesa::CurrencyInfoApi* | [**info_currencies**](docs/CurrencyInfoApi.md#info_currencies) | **GET** /info/currencies | Getting a list of possible requested currencies
*Bitpesa::CurrencyInfoApi* | [**info_currencies_in**](docs/CurrencyInfoApi.md#info_currencies_in) | **GET** /info/currencies/in | Getting a list of possible input currencies
*Bitpesa::CurrencyInfoApi* | [**info_currencies_out**](docs/CurrencyInfoApi.md#info_currencies_out) | **GET** /info/currencies/out | Getting a list of possible output currencies
*Bitpesa::DocumentsApi* | [**get_document**](docs/DocumentsApi.md#get_document) | **GET** /documents/{Document ID} | Fetching a document
*Bitpesa::DocumentsApi* | [**get_documents**](docs/DocumentsApi.md#get_documents) | **GET** /documents | Getting a list of documents
*Bitpesa::DocumentsApi* | [**post_documents**](docs/DocumentsApi.md#post_documents) | **POST** /documents | Creating a document
*Bitpesa::LogsApi* | [**get_webhook_log**](docs/LogsApi.md#get_webhook_log) | **GET** /logs/{Webhook Log ID} | Fetch an individual webhook log
*Bitpesa::LogsApi* | [**get_webhook_logs**](docs/LogsApi.md#get_webhook_logs) | **GET** /logs/webhooks | Fetch a list of webhook logs
*Bitpesa::PaymentMethodsApi* | [**payment_methods_in**](docs/PaymentMethodsApi.md#payment_methods_in) | **GET** /info/payment_methods/in | This method returns possible payin methods.
*Bitpesa::PaymentMethodsApi* | [**payment_methods_out**](docs/PaymentMethodsApi.md#payment_methods_out) | **GET** /info/payment_methods/out | This method returns possible payout methods.
*Bitpesa::PayoutMethodsApi* | [**delete_payout_method**](docs/PayoutMethodsApi.md#delete_payout_method) | **DELETE** /payout_methods/{Payout Method ID} | Deleting a payout method
*Bitpesa::PayoutMethodsApi* | [**get_payout_method**](docs/PayoutMethodsApi.md#get_payout_method) | **GET** /payout_methods/{Payout Method ID} | Fetching a payout method
*Bitpesa::PayoutMethodsApi* | [**get_payout_methods**](docs/PayoutMethodsApi.md#get_payout_methods) | **GET** /payout_methods | Listing payout methods
*Bitpesa::PayoutMethodsApi* | [**patch_payout_method**](docs/PayoutMethodsApi.md#patch_payout_method) | **PATCH** /payout_methods/{Payout Method ID} | Updating a payout method
*Bitpesa::PayoutMethodsApi* | [**post_payout_methods**](docs/PayoutMethodsApi.md#post_payout_methods) | **POST** /payout_methods | Creating a payout method
*Bitpesa::RecipientsApi* | [**delete_recipient**](docs/RecipientsApi.md#delete_recipient) | **DELETE** /recipients/{Recipient ID} | Cancelling a recipient
*Bitpesa::RecipientsApi* | [**get_recipients**](docs/RecipientsApi.md#get_recipients) | **GET** /recipients | Getting a list of recipients with filtering
*Bitpesa::RecipientsApi* | [**patch_recipient**](docs/RecipientsApi.md#patch_recipient) | **PATCH** /recipients/{Recipient ID} | Updating a recipient
*Bitpesa::SendersApi* | [**delete_sender**](docs/SendersApi.md#delete_sender) | **DELETE** /senders/{Sender ID} | Deleting a sender
*Bitpesa::SendersApi* | [**get_sender**](docs/SendersApi.md#get_sender) | **GET** /senders/{Sender ID} | Fetching a sender
*Bitpesa::SendersApi* | [**get_senders**](docs/SendersApi.md#get_senders) | **GET** /senders | Listing senders
*Bitpesa::SendersApi* | [**patch_sender**](docs/SendersApi.md#patch_sender) | **PATCH** /senders/{Sender ID} | Updating a sender
*Bitpesa::SendersApi* | [**post_senders**](docs/SendersApi.md#post_senders) | **POST** /senders | Creating a sender
*Bitpesa::TransactionsApi* | [**calculate_transactions**](docs/TransactionsApi.md#calculate_transactions) | **POST** /transactions/calculate | Calculates transaction amounts for a transaction payload
*Bitpesa::TransactionsApi* | [**get_transaction**](docs/TransactionsApi.md#get_transaction) | **GET** /transactions/{Transaction ID} | Fetch a single transaction
*Bitpesa::TransactionsApi* | [**get_transactions**](docs/TransactionsApi.md#get_transactions) | **GET** /transactions | Get a list of transactions
*Bitpesa::TransactionsApi* | [**payin_transaction**](docs/TransactionsApi.md#payin_transaction) | **POST** /transactions/{Transaction ID}/payin | Creates a fake payin for transaction
*Bitpesa::TransactionsApi* | [**payout_transaction**](docs/TransactionsApi.md#payout_transaction) | **POST** /transactions/{Transaction ID}/payout | Creates a fake payout for transaction
*Bitpesa::TransactionsApi* | [**post_transactions**](docs/TransactionsApi.md#post_transactions) | **POST** /transactions | Creates a new transaction
*Bitpesa::TransactionsApi* | [**validate_transactions**](docs/TransactionsApi.md#validate_transactions) | **POST** /transactions/validate | Validates a transaction payload
*Bitpesa::WebhooksApi* | [**delete_webhook**](docs/WebhooksApi.md#delete_webhook) | **DELETE** /webhooks/{Webhook ID} | Unsubscribing from a webhook
*Bitpesa::WebhooksApi* | [**get_webhook**](docs/WebhooksApi.md#get_webhook) | **GET** /webhooks/{Webhook ID} | Find a webhook's details
*Bitpesa::WebhooksApi* | [**get_webhook_events**](docs/WebhooksApi.md#get_webhook_events) | **GET** /webhooks/events | Find possible webhook events
*Bitpesa::WebhooksApi* | [**get_webhooks**](docs/WebhooksApi.md#get_webhooks) | **GET** /webhooks | Listing webhooks
*Bitpesa::WebhooksApi* | [**post_webhooks**](docs/WebhooksApi.md#post_webhooks) | **POST** /webhooks | Creating a webhook


## Documentation for Models

 - [Bitpesa::Account](docs/Account.md)
 - [Bitpesa::AccountListResponse](docs/AccountListResponse.md)
 - [Bitpesa::AccountMeta](docs/AccountMeta.md)
 - [Bitpesa::AccountResponse](docs/AccountResponse.md)
 - [Bitpesa::AccountValidationError](docs/AccountValidationError.md)
 - [Bitpesa::AccountValidationRequest](docs/AccountValidationRequest.md)
 - [Bitpesa::AccountValidationResponse](docs/AccountValidationResponse.md)
 - [Bitpesa::AccountValidationResult](docs/AccountValidationResult.md)
 - [Bitpesa::ApiLog](docs/ApiLog.md)
 - [Bitpesa::ApiLogListResponse](docs/ApiLogListResponse.md)
 - [Bitpesa::ApiLogResponse](docs/ApiLogResponse.md)
 - [Bitpesa::Currency](docs/Currency.md)
 - [Bitpesa::CurrencyExchange](docs/CurrencyExchange.md)
 - [Bitpesa::CurrencyExchangeListResponse](docs/CurrencyExchangeListResponse.md)
 - [Bitpesa::CurrencyListResponse](docs/CurrencyListResponse.md)
 - [Bitpesa::CurrencyOpposite](docs/CurrencyOpposite.md)
 - [Bitpesa::Debit](docs/Debit.md)
 - [Bitpesa::DebitListRequest](docs/DebitListRequest.md)
 - [Bitpesa::DebitListResponse](docs/DebitListResponse.md)
 - [Bitpesa::DebitRequest](docs/DebitRequest.md)
 - [Bitpesa::DebitRequestWrapper](docs/DebitRequestWrapper.md)
 - [Bitpesa::DebitResponse](docs/DebitResponse.md)
 - [Bitpesa::Document](docs/Document.md)
 - [Bitpesa::DocumentListResponse](docs/DocumentListResponse.md)
 - [Bitpesa::DocumentRequest](docs/DocumentRequest.md)
 - [Bitpesa::DocumentResponse](docs/DocumentResponse.md)
 - [Bitpesa::DocumentWebhook](docs/DocumentWebhook.md)
 - [Bitpesa::ErrorStatus](docs/ErrorStatus.md)
 - [Bitpesa::FieldDescription](docs/FieldDescription.md)
 - [Bitpesa::FieldSelectValidation](docs/FieldSelectValidation.md)
 - [Bitpesa::FieldValidation](docs/FieldValidation.md)
 - [Bitpesa::Pagination](docs/Pagination.md)
 - [Bitpesa::PaginationMeta](docs/PaginationMeta.md)
 - [Bitpesa::PayinMethod](docs/PayinMethod.md)
 - [Bitpesa::PayinMethodDetails](docs/PayinMethodDetails.md)
 - [Bitpesa::PayinMethodDetailsMobile](docs/PayinMethodDetailsMobile.md)
 - [Bitpesa::PayinMethodDetailsNGNBank](docs/PayinMethodDetailsNGNBank.md)
 - [Bitpesa::PayinMethodRequest](docs/PayinMethodRequest.md)
 - [Bitpesa::PaymentMethod](docs/PaymentMethod.md)
 - [Bitpesa::PaymentMethodListResponse](docs/PaymentMethodListResponse.md)
 - [Bitpesa::PaymentMethodOpposite](docs/PaymentMethodOpposite.md)
 - [Bitpesa::PayoutMethod](docs/PayoutMethod.md)
 - [Bitpesa::PayoutMethodBankAccountTypeEnum](docs/PayoutMethodBankAccountTypeEnum.md)
 - [Bitpesa::PayoutMethodDetails](docs/PayoutMethodDetails.md)
 - [Bitpesa::PayoutMethodDetailsBalance](docs/PayoutMethodDetailsBalance.md)
 - [Bitpesa::PayoutMethodDetailsGHSBank](docs/PayoutMethodDetailsGHSBank.md)
 - [Bitpesa::PayoutMethodDetailsIBAN](docs/PayoutMethodDetailsIBAN.md)
 - [Bitpesa::PayoutMethodDetailsMADCash](docs/PayoutMethodDetailsMADCash.md)
 - [Bitpesa::PayoutMethodDetailsMobile](docs/PayoutMethodDetailsMobile.md)
 - [Bitpesa::PayoutMethodDetailsNGNBank](docs/PayoutMethodDetailsNGNBank.md)
 - [Bitpesa::PayoutMethodDetailsXOFMobile](docs/PayoutMethodDetailsXOFMobile.md)
 - [Bitpesa::PayoutMethodGenderEnum](docs/PayoutMethodGenderEnum.md)
 - [Bitpesa::PayoutMethodIdentityCardTypeEnum](docs/PayoutMethodIdentityCardTypeEnum.md)
 - [Bitpesa::PayoutMethodListResponse](docs/PayoutMethodListResponse.md)
 - [Bitpesa::PayoutMethodMobileProviderEnum](docs/PayoutMethodMobileProviderEnum.md)
 - [Bitpesa::PayoutMethodRequest](docs/PayoutMethodRequest.md)
 - [Bitpesa::PayoutMethodResponse](docs/PayoutMethodResponse.md)
 - [Bitpesa::PayoutMethodWebhook](docs/PayoutMethodWebhook.md)
 - [Bitpesa::Recipient](docs/Recipient.md)
 - [Bitpesa::RecipientListResponse](docs/RecipientListResponse.md)
 - [Bitpesa::RecipientRequest](docs/RecipientRequest.md)
 - [Bitpesa::RecipientResponse](docs/RecipientResponse.md)
 - [Bitpesa::RecipientState](docs/RecipientState.md)
 - [Bitpesa::RecipientWebhook](docs/RecipientWebhook.md)
 - [Bitpesa::Sender](docs/Sender.md)
 - [Bitpesa::SenderListResponse](docs/SenderListResponse.md)
 - [Bitpesa::SenderRequest](docs/SenderRequest.md)
 - [Bitpesa::SenderResponse](docs/SenderResponse.md)
 - [Bitpesa::SenderResponseExisting](docs/SenderResponseExisting.md)
 - [Bitpesa::SenderResponseMeta](docs/SenderResponseMeta.md)
 - [Bitpesa::SenderState](docs/SenderState.md)
 - [Bitpesa::SenderWebhook](docs/SenderWebhook.md)
 - [Bitpesa::Transaction](docs/Transaction.md)
 - [Bitpesa::TransactionListResponse](docs/TransactionListResponse.md)
 - [Bitpesa::TransactionRequest](docs/TransactionRequest.md)
 - [Bitpesa::TransactionResponse](docs/TransactionResponse.md)
 - [Bitpesa::TransactionResponseExisting](docs/TransactionResponseExisting.md)
 - [Bitpesa::TransactionResponseMeta](docs/TransactionResponseMeta.md)
 - [Bitpesa::TransactionState](docs/TransactionState.md)
 - [Bitpesa::TransactionTraits](docs/TransactionTraits.md)
 - [Bitpesa::TransactionWebhook](docs/TransactionWebhook.md)
 - [Bitpesa::ValidationErrorDescription](docs/ValidationErrorDescription.md)
 - [Bitpesa::Webhook](docs/Webhook.md)
 - [Bitpesa::WebhookDefinition](docs/WebhookDefinition.md)
 - [Bitpesa::WebhookDefinitionEventListResponse](docs/WebhookDefinitionEventListResponse.md)
 - [Bitpesa::WebhookDefinitionListResponse](docs/WebhookDefinitionListResponse.md)
 - [Bitpesa::WebhookDefinitionRequest](docs/WebhookDefinitionRequest.md)
 - [Bitpesa::WebhookDefinitionResponse](docs/WebhookDefinitionResponse.md)
 - [Bitpesa::WebhookLog](docs/WebhookLog.md)
 - [Bitpesa::WebhookLogListResponse](docs/WebhookLogListResponse.md)
 - [Bitpesa::WebhookLogMetadata](docs/WebhookLogMetadata.md)
 - [Bitpesa::WebhookLogMetadataRequest](docs/WebhookLogMetadataRequest.md)
 - [Bitpesa::WebhookLogMetadataResponse](docs/WebhookLogMetadataResponse.md)
 - [Bitpesa::WebhookLogResponse](docs/WebhookLogResponse.md)


## Documentation for Authorization

You can set the API Key and Secret on the ApiClient object for authentication:


```ruby
# Load the gem
require 'bitpesa'

# Setup authorization

Bitpesa.configure do |config|
  config.api_key = 'YOUR API KEY'
  config.api_secret = 'YOUR API SECRET'
  config.host = "https://api-sandbox.bitpesa.co/v1"
end

begin
  request = Bitpesa::AccountValidationRequest.new # account validation api
  request.bank_account = '9040004458219'
  request.bank_code = '020100'
  request.country = 'GH'
  request.currency = 'GHS'
  request.method = 'bank'

  avi = Bitpesa::AccountValidationApi.new
  account_validation = avi.post_account_validations(request)
  account_name = account_validation.object.account_name
  puts "Account Name: #{account_name}"
rescue Bitpesa::ApiError => e
  if e.validation_error
    puts e.response_object("AccountValidationResponse").meta.error
  else
    puts "Exception when calling AccountValidationApi#account_validation_example: #{e}"
  end
end
```
